summaryrefslogtreecommitdiffstats
path: root/kword/KWAnchor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWAnchor.cpp')
-rw-r--r--kword/KWAnchor.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kword/KWAnchor.cpp b/kword/KWAnchor.cpp
index f9641cf4..11136e3d 100644
--- a/kword/KWAnchor.cpp
+++ b/kword/KWAnchor.cpp
@@ -154,8 +154,8 @@ void KWAnchor::draw( TQPainter* p, int x, int y, int cx, int cy, int cw, int ch,
if ( containingFrame ) // 0 in the textviewmode
topLeftParagPt = containingFrame->innerRect().topLeft();
- topLeftParagPt.rx() += zh->tqlayoutUnitPtToPt( zh->pixelYToPt( paragx ) );
- topLeftParagPt.ry() += zh->tqlayoutUnitPtToPt( zh->pixelYToPt( paragy ) );
+ topLeftParagPt.rx() += zh->layoutUnitPtToPt( zh->pixelYToPt( paragx ) );
+ topLeftParagPt.ry() += zh->layoutUnitPtToPt( zh->pixelYToPt( paragy ) );
if ( containingFrame ) // 0 in the textviewmode
topLeftParagPt.ry() -= containingFrame->internalY();
@@ -205,8 +205,8 @@ TQSize KWAnchor::size() const
KoTextZoomHandler * zh = textDocument()->formattingZoomHandler();
TQSize sz( zh->ptToLayoutUnitPixX( kosz.width() ), zh->ptToLayoutUnitPixY( kosz.height() ) );
//kdDebug() << "KWAnchor::size in LU: " << sz.width() << "x" << sz.height() << endl;
//kdDebug() << " size in pixels: " << zh->tqlayoutUnitToPixelX( sz.width() ) << "x"
// << zh->tqlayoutUnitToPixelY( sz.height() ) << endl;
if ( sz.isNull() ) // for some reason, we don't know the size yet
sz = TQSize( width, height ); // LU
return sz;
@@ -263,10 +263,10 @@ void KWAnchor::setDeleted( bool b )
m_frameset->setAnchored( static_cast<KWTextDocument *>(textDocument())->textFrameSet() );
}
-void KWAnchor::save( TQDomElement &tqparentElem )
+void KWAnchor::save( TQDomElement &parentElem )
{
- TQDomElement anchorElem = tqparentElem.ownerDocument().createElement( "ANCHOR" );
- tqparentElem.appendChild( anchorElem );
+ TQDomElement anchorElem = parentElem.ownerDocument().createElement( "ANCHOR" );
+ parentElem.appendChild( anchorElem );
anchorElem.setAttribute( "type", "frameset" ); // the only possible value currently
//KWDocument * doc = textDocument()->textFrameSet()->kWordDocument();
// ## TODO save the frame number as well ? Only the first frame ? to be determined
@@ -205,8 +205,8 @@ TQSize KWAnchor::size() const
TQSize sz( zh->ptToLayoutUnitPixX( kosz.width() ), zh->ptToLayoutUnitPixY( kosz.height() ) );
//kdDebug() << "KWAnchor::size in LU: " << sz.width() << "x" << sz.height() << endl;
- //kdDebug() << " size in pixels: " << zh->tqlayoutUnitToPixelX( sz.width() ) << "x"
- // << zh->tqlayoutUnitToPixelY( sz.height() ) << endl;
+ //kdDebug() << " size in pixels: " << zh->layoutUnitToPixelX( sz.width() ) << "x"
+ // << zh->layoutUnitToPixelY( sz.height() ) << endl;
if ( sz.isNull() ) // for some reason, we don't know the size yet
sz = TQSize( width, height ); // LU